@@ -1,4 +1,4 @@
-/*Copyright (c) 1993-1995 Xerox Corporation.  All Rights Reserved.
+/*Copyright (c) 1993-1997 Xerox Corporation.  All Rights Reserved.
 
   Permission to use, copy, modify  and  distribute  without  charge
   this  software,  documentation, images, etc. is granted, provided
@@ -35,6 +35,7 @@ XrmOptionDescRec op_table[] = {         /*Argument operation resource table*/
                 {"-c", ".console",   XrmoptionIsArg,  (caddr_t) NULL},
                 {"-display", ".display",   XrmoptionSepArg, (caddr_t) NULL},
                 {"-f", ".saveto",    XrmoptionSepArg, (caddr_t) NULL},
+		{"-i", ".ignore",    XrmoptionSepArg, (caddr_t) NULL},
                 {"-m", ".missing",   XrmoptionSepArg, (caddr_t) NULL},
                 {"-r", ".remote",    XrmoptionSepArg, (caddr_t) NULL},
                 {"-s", ".screens",   XrmoptionSepArg, (caddr_t) NULL},
@@ -286,7 +287,7 @@ extract_options()
         char *str_type[20];
         XrmValue value;
         extern int console_checking;
-        extern char *addon,*missing,*remote,*list;
+        extern char *addon,*ignore,*missing,*remote,*list;
 
         /*Allocate space for the names of the resources we'll be looking
           for*/
@@ -323,6 +324,16 @@ extract_options()
           }
         open_file(filename);
 
+	/*Get list of applications to ignore (-i)*/
+	ignore = NULL;
+	sprintf(resource,"%s.ignore",program);
+	if(XrmGetResource(database,resource,"xtoolplaces.ignore",
+			  str_type,&value) == True)
+	  if(value.addr && ((ignore = strdup(value.addr)) == NULL)) {
+	    perror(program);
+	    exit(1);
+	  }
+
         /*Get missing applications list (-m)*/
         missing = NULL;
         sprintf(resource,"%s.missing",program);
